==> estateplat-common-1.1.0-20170118.105901-253-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjZhxx.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * 宗海信息实体类
 * Created by zhx on 2016/1/5
 */
public class DjsjZhxx {
    private String zhDjdcbIndex;//主键
    private String zhdm;//宗海代码
    private String bdcdyh;//不动产单元号
    private String zhtzm;//宗海特征码
    private String xmmc;//项目名称
    private String xmxz;//项目性质
    private Double yhzmj;//用海总面积
    private Double zhmj;//宗海面积
    private String db;//海域等别
    private Double zhax;//占海岸线
    private String yhlxa;//用海类型A
    private String yhlxb;//用海类型B
    private String yhwzsm;//用海位置说明
    private String hdmc;//海岛名称
    private String hddm;//海岛代码
    private String ydfw;//用岛范围
    private Double ydmj;//用岛面积
    private String hdwz;//海岛位置
    private String hdyt;//海岛用途
    private String bdcdyzt;//不动产单元状态
    private Date jlrq;//建立日期
    private Date gxrq;//更新日期
    private String syjbzyj;//使用金标准依据
    private String syjjnqk;//使用金缴纳情况
    private String jlbclr;//记录表测量人
    private String jlbshr;//记录表审核人
    private String jlbcldw;//记录表测量单位
    private String jlbsdjz;//记录表深度记录
    private Date jlbclrq;//记录表测量日期
    private String gzwlx;//构筑物类型
    private String qlrmc;//权利人名称
    private String qlrzjlx;//权利人证件类型
    private String qlrzjh;//权利人证件号
    private String frdbxm;//法人代表姓名
    private String frdbzjlx;//法人代表证件类型
    private String frdbzjh;//法人代表证件号
    private String frdbdhhm;//法人代表电话号码
    private String dlrxm;//代理人姓名
    private String mjdw;//面积单位
    private String dlrzjlx;//代理人证件类型
    private String dlrzjh;//代理人证件号
    private String dlrdhhm;//代理人电话号码
    private String dwxz;//单位性质
    private String sjzgbm;//上级主管部门
    private Double dymj;//独用面积
    private Double ftmj;//分摊面积
    private Integer xh;//序号
    private Double symj;//使用面积
    private String txdz;//通讯地址
    private String qlrlx;//权利人类型
    private String qlrlxdh;//权利人联系电话
    private String qlryb;//权利人邮编

    public String getZhDjdcbIndex() {
        return zhDjdcbIndex;
    }

    public void setZhDjdcbIndex(String zhDjdcbIndex) {
        this.zhDjdcbIndex = zhDjdcbIndex;
    }

    public String getZhdm() {
        return zhdm;
    }

    public void setZhdm(String zhdm) {
        this.zhdm = zhdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZhtzm() {
        return zhtzm;
    }

    public void setZhtzm(String zhtzm) {
        this.zhtzm = zhtzm;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXmxz() {
        return xmxz;
    }

    public void setXmxz(String xmxz) {
        this.xmxz = xmxz;
    }

    public Double getYhzmj() {
        return yhzmj;
    }

    public void setYhzmj(Double yhzmj) {
        this.yhzmj = yhzmj;
    }

    public Double getZhmj() {
        return zhmj;
    }

    public void setZhmj(Double zhmj) {
        this.zhmj = zhmj;
    }

    public String getDb() {
        return db;
    }

    public void setDb(String db) {
        this.db = db;
    }

    public Double getZhax() {
        return zhax;
    }

    public void setZhax(Double zhax) {
        this.zhax = zhax;
    }

    public String getYhlxa() {
        return yhlxa;
    }

    public void setYhlxa(String yhlxa) {
        this.yhlxa = yhlxa;
    }

    public String getYhlxb() {
        return yhlxb;
    }

    public void setYhlxb(String yhlxb) {
        this.yhlxb = yhlxb;
    }

    public String getYhwzsm() {
        return yhwzsm;
    }

    public void setYhwzsm(String yhwzsm) {
        this.yhwzsm = yhwzsm;
    }

    public String getHdmc() {
        return hdmc;
    }

    public void setHdmc(String hdmc) {
        this.hdmc = hdmc;
    }

    public String getHddm() {
        return hddm;
    }

    public void setHddm(String hddm) {
        this.hddm = hddm;
    }

    public String getYdfw() {
        return ydfw;
    }

    public void setYdfw(String ydfw) {
        this.ydfw = ydfw;
    }

    public Double getYdmj() {
        return ydmj;
    }

    public void setYdmj(Double ydmj) {
        this.ydmj = ydmj;
    }

    public String getHdwz() {
        return hdwz;
    }

    public void setHdwz(String hdwz) {
        this.hdwz = hdwz;
    }

    public String getHdyt() {
        return hdyt;
    }

    public void setHdyt(String hdyt) {
        this.hdyt = hdyt;
    }

    public String getBdcdyzt() {
        return bdcdyzt;
    }

    public void setBdcdyzt(String bdcdyzt) {
        this.bdcdyzt = bdcdyzt;
    }

    public Date getJlrq() {
        return jlrq;
    }

    public void setJlrq(Date jlrq) {
        this.jlrq = jlrq;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getSyjbzyj() {
        return syjbzyj;
    }

    public void setSyjbzyj(String syjbzyj) {
        this.syjbzyj = syjbzyj;
    }

    public String getSyjjnqk() {
        return syjjnqk;
    }

    public void setSyjjnqk(String syjjnqk) {
        this.syjjnqk = syjjnqk;
    }

    public String getJlbclr() {
        return jlbclr;
    }

    public void setJlbclr(String jlbclr) {
        this.jlbclr = jlbclr;
    }

    public String getJlbshr() {
        return jlbshr;
    }

    public void setJlbshr(String jlbshr) {
        this.jlbshr = jlbshr;
    }

    public String getJlbcldw() {
        return jlbcldw;
    }

    public void setJlbcldw(String jlbcldw) {
        this.jlbcldw = jlbcldw;
    }

    public String getJlbsdjz() {
        return jlbsdjz;
    }

    public void setJlbsdjz(String jlbsdjz) {
        this.jlbsdjz = jlbsdjz;
    }

    public Date getJlbclrq() {
        return jlbclrq;
    }

    public void setJlbclrq(Date jlbclrq) {
        this.jlbclrq = jlbclrq;
    }

    public String getGzwlx() {
        return gzwlx;
    }

    public void setGzwlx(String gzwlx) {
        this.gzwlx = gzwlx;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrzjlx() {
        return qlrzjlx;
    }

    public void setQlrzjlx(String qlrzjlx) {
        this.qlrzjlx = qlrzjlx;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getFrdbxm() {
        return frdbxm;
    }

    public void setFrdbxm(String frdbxm) {
        this.frdbxm = frdbxm;
    }

    public String getFrdbzjlx() {
        return frdbzjlx;
    }

    public void setFrdbzjlx(String frdbzjlx) {
        this.frdbzjlx = frdbzjlx;
    }

    public String getFrdbzjh() {
        return frdbzjh;
    }

    public void setFrdbzjh(String frdbzjh) {
        this.frdbzjh = frdbzjh;
    }

    public String getFrdbdhhm() {
        return frdbdhhm;
    }

    public void setFrdbdhhm(String frdbdhhm) {
        this.frdbdhhm = frdbdhhm;
    }

    public String getDlrxm() {
        return dlrxm;
    }

    public void setDlrxm(String dlrxm) {
        this.dlrxm = dlrxm;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getDlrzjlx() {
        return dlrzjlx;
    }

    public void setDlrzjlx(String dlrzjlx) {
        this.dlrzjlx = dlrzjlx;
    }

    public String getDlrzjh() {
        return dlrzjh;
    }

    public void setDlrzjh(String dlrzjh) {
        this.dlrzjh = dlrzjh;
    }

    public String getDlrdhhm() {
        return dlrdhhm;
    }

    public void setDlrdhhm(String dlrdhhm) {
        this.dlrdhhm = dlrdhhm;
    }

    public String getDwxz() {
        return dwxz;
    }

    public void setDwxz(String dwxz) {
        this.dwxz = dwxz;
    }

    public String getSjzgbm() {
        return sjzgbm;
    }

    public void setSjzgbm(String sjzgbm) {
        this.sjzgbm = sjzgbm;
    }

    public Double getDymj() {
        return dymj;
    }

    public void setDymj(Double dymj) {
        this.dymj = dymj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public Double getSymj() {
        return symj;
    }

    public void setSymj(Double symj) {
        this.symj = symj;
    }

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlrlxdh() {
        return qlrlxdh;
    }

    public void setQlrlxdh(String qlrlxdh) {
        this.qlrlxdh = qlrlxdh;
    }

    public String getQlryb() {
        return qlryb;
    }

    public void setQlryb(String qlryb) {
        this.qlryb = qlryb;
    }

}

==> estateplat-common-1.2.1-20170727.080233-71-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjZhxx.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * 宗海信息实体类
 * Created by zhx on 2016/1/5
 */
public class DjsjZhxx {
    private String zhDjdcbIndex;//主键
    private String zhdm;//宗海代码
    private String bdcdyh;//不动产单元号
    private String zhtzm;//宗海特征码
    private String xmmc;//项目名称
    private String xmxz;//项目性质
    private Double yhzmj;//用海总面积
    private Double zhmj;//宗海面积
    private String db;//海域等别
    private Double zhax;//占海岸线
    private String yhlxa;//用海类型A
    private String yhlxb;//用海类型B
    private String yhwzsm;//用海位置说明
    private String hdmc;//海岛名称
    private String hddm;//海岛代码
    private String ydfw;//用岛范围
    private Double ydmj;//用岛面积
    private String hdwz;//海岛位置
    private String hdyt;//海岛用途
    private String bdcdyzt;//不动产单元状态
    private Date jlrq;//建立日期
    private Date gxrq;//更新日期
    private String syjbzyj;//使用金标准依据
    private String syjjnqk;//使用金缴纳情况
    private String jlbclr;//记录表测量人
    private String jlbshr;//记录表审核人
    private String jlbcldw;//记录表测量单位
    private String jlbsdjz;//记录表深度记录
    private Date jlbclrq;//记录表测量日期
    private String gzwlx;//构筑物类型
    private String qlrmc;//权利人名称
    private String qlrzjlx;//权利人证件类型
    private String qlrzjh;//权利人证件号
    private String frdbxm;//法人代表姓名
    private String frdbzjlx;//法人代表证件类型
    private String frdbzjh;//法人代表证件号
    private String frdbdhhm;//法人代表电话号码
    private String dlrxm;//代理人姓名
    private String mjdw;//面积单位
    private String dlrzjlx;//代理人证件类型
    private String dlrzjh;//代理人证件号
    private String dlrdhhm;//代理人电话号码
    private String dwxz;//单位性质
    private String sjzgbm;//上级主管部门
    private Double dymj;//独用面积
    private Double ftmj;//分摊面积
    private Integer xh;//序号
    private Double symj;//使用面积
    private String txdz;//通讯地址
    private String qlrlx;//权利人类型
    private String qlrlxdh;//权利人联系电话
    private String qlryb;//权利人邮编
    private String yhspdw;//用海审批单位
    private String pzwh;//批注文号
    private String hyglbh;//用海管理编号

    public String getZhDjdcbIndex() {
        return zhDjdcbIndex;
    }

    public void setZhDjdcbIndex(String zhDjdcbIndex) {
        this.zhDjdcbIndex = zhDjdcbIndex;
    }

    public String getZhdm() {
        return zhdm;
    }

    public void setZhdm(String zhdm) {
        this.zhdm = zhdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZhtzm() {
        return zhtzm;
    }

    public void setZhtzm(String zhtzm) {
        this.zhtzm = zhtzm;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXmxz() {
        return xmxz;
    }

    public void setXmxz(String xmxz) {
        this.xmxz = xmxz;
    }

    public Double getYhzmj() {
        return yhzmj;
    }

    public void setYhzmj(Double yhzmj) {
        this.yhzmj = yhzmj;
    }

    public Double getZhmj() {
        return zhmj;
    }

    public void setZhmj(Double zhmj) {
        this.zhmj = zhmj;
    }

    public String getDb() {
        return db;
    }

    public void setDb(String db) {
        this.db = db;
    }

    public Double getZhax() {
        return zhax;
    }

    public void setZhax(Double zhax) {
        this.zhax = zhax;
    }

    public String getYhlxa() {
        return yhlxa;
    }

    public void setYhlxa(String yhlxa) {
        this.yhlxa = yhlxa;
    }

    public String getYhlxb() {
        return yhlxb;
    }

    public void setYhlxb(String yhlxb) {
        this.yhlxb = yhlxb;
    }

    public String getYhwzsm() {
        return yhwzsm;
    }

    public void setYhwzsm(String yhwzsm) {
        this.yhwzsm = yhwzsm;
    }

    public String getHdmc() {
        return hdmc;
    }

    public void setHdmc(String hdmc) {
        this.hdmc = hdmc;
    }

    public String getHddm() {
        return hddm;
    }

    public void setHddm(String hddm) {
        this.hddm = hddm;
    }

    public String getYdfw() {
        return ydfw;
    }

    public void setYdfw(String ydfw) {
        this.ydfw = ydfw;
    }

    public Double getYdmj() {
        return ydmj;
    }

    public void setYdmj(Double ydmj) {
        this.ydmj = ydmj;
    }

    public String getHdwz() {
        return hdwz;
    }

    public void setHdwz(String hdwz) {
        this.hdwz = hdwz;
    }

    public String getHdyt() {
        return hdyt;
    }

    public void setHdyt(String hdyt) {
        this.hdyt = hdyt;
    }

    public String getBdcdyzt() {
        return bdcdyzt;
    }

    public void setBdcdyzt(String bdcdyzt) {
        this.bdcdyzt = bdcdyzt;
    }

    public Date getJlrq() {
        return jlrq;
    }

    public void setJlrq(Date jlrq) {
        this.jlrq = jlrq;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getSyjbzyj() {
        return syjbzyj;
    }

    public void setSyjbzyj(String syjbzyj) {
        this.syjbzyj = syjbzyj;
    }

    public String getSyjjnqk() {
        return syjjnqk;
    }

    public void setSyjjnqk(String syjjnqk) {
        this.syjjnqk = syjjnqk;
    }

    public String getJlbclr() {
        return jlbclr;
    }

    public void setJlbclr(String jlbclr) {
        this.jlbclr = jlbclr;
    }

    public String getJlbshr() {
        return jlbshr;
    }

    public void setJlbshr(String jlbshr) {
        this.jlbshr = jlbshr;
    }

    public String getJlbcldw() {
        return jlbcldw;
    }

    public void setJlbcldw(String jlbcldw) {
        this.jlbcldw = jlbcldw;
    }

    public String getJlbsdjz() {
        return jlbsdjz;
    }

    public void setJlbsdjz(String jlbsdjz) {
        this.jlbsdjz = jlbsdjz;
    }

    public Date getJlbclrq() {
        return jlbclrq;
    }

    public void setJlbclrq(Date jlbclrq) {
        this.jlbclrq = jlbclrq;
    }

    public String getGzwlx() {
        return gzwlx;
    }

    public void setGzwlx(String gzwlx) {
        this.gzwlx = gzwlx;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrzjlx() {
        return qlrzjlx;
    }

    public void setQlrzjlx(String qlrzjlx) {
        this.qlrzjlx = qlrzjlx;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getFrdbxm() {
        return frdbxm;
    }

    public void setFrdbxm(String frdbxm) {
        this.frdbxm = frdbxm;
    }

    public String getFrdbzjlx() {
        return frdbzjlx;
    }

    public void setFrdbzjlx(String frdbzjlx) {
        this.frdbzjlx = frdbzjlx;
    }

    public String getFrdbzjh() {
        return frdbzjh;
    }

    public void setFrdbzjh(String frdbzjh) {
        this.frdbzjh = frdbzjh;
    }

    public String getFrdbdhhm() {
        return frdbdhhm;
    }

    public void setFrdbdhhm(String frdbdhhm) {
        this.frdbdhhm = frdbdhhm;
    }

    public String getDlrxm() {
        return dlrxm;
    }

    public void setDlrxm(String dlrxm) {
        this.dlrxm = dlrxm;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getDlrzjlx() {
        return dlrzjlx;
    }

    public void setDlrzjlx(String dlrzjlx) {
        this.dlrzjlx = dlrzjlx;
    }

    public String getDlrzjh() {
        return dlrzjh;
    }

    public void setDlrzjh(String dlrzjh) {
        this.dlrzjh = dlrzjh;
    }

    public String getDlrdhhm() {
        return dlrdhhm;
    }

    public void setDlrdhhm(String dlrdhhm) {
        this.dlrdhhm = dlrdhhm;
    }

    public String getDwxz() {
        return dwxz;
    }

    public void setDwxz(String dwxz) {
        this.dwxz = dwxz;
    }

    public String getSjzgbm() {
        return sjzgbm;
    }

    public void setSjzgbm(String sjzgbm) {
        this.sjzgbm = sjzgbm;
    }

    public Double getDymj() {
        return dymj;
    }

    public void setDymj(Double dymj) {
        this.dymj = dymj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public Double getSymj() {
        return symj;
    }

    public void setSymj(Double symj) {
        this.symj = symj;
    }

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlrlxdh() {
        return qlrlxdh;
    }

    public void setQlrlxdh(String qlrlxdh) {
        this.qlrlxdh = qlrlxdh;
    }

    public String getQlryb() {
        return qlryb;
    }

    public void setQlryb(String qlryb) {
        this.qlryb = qlryb;
    }

    public String getYhspdw() {
        return yhspdw;
    }

    public void setYhspdw(String yhspdw) {
        this.yhspdw = yhspdw;
    }

    public String getPzwh() {
        return pzwh;
    }

    public void setPzwh(String pzwh) {
        this.pzwh = pzwh;
    }

    public String getHyglbh() {
        return hyglbh;
    }

    public void setHyglbh(String hyglbh) {
        this.hyglbh = hyglbh;
    }
}
